@@ -1,7 +1,7 @@
 package Algorithm::LUHN_XS;
-$Algorithm::LUHN_XS::VERSION = '1.02';
+$Algorithm::LUHN_XS::VERSION = '1.03';
 require XSLoader;
-XSLoader::load();
+XSLoader::load('Algorithm::LUHN_XS', $VERSION);
 use 5.006;
 use strict;
 use warnings;
